==> open-xchange-core_7.8.1.orig.tar.bz2: open-xchange-core-7.8.1/com.openexchange.http.client/src/com/openexchange/http/client/osgi/HTTPClientActivator.java <==
/*-
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */


package com.openexchange.http.client.osgi;

import org.osgi.framework.ServiceReference;
import com.openexchange.filemanagement.ManagedFileManagement;
import com.openexchange.http.client.HTTPClient;
import com.openexchange.http.client.apache.ApacheHTTPClient;
import com.openexchange.http.client.builder.HTTPResponseProcessor;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.osgi.SimpleRegistryListener;


public class HTTPClientActivator extends HousekeepingActivator {

	@Override
	protected Class<?>[] getNeededServices() {
		return new Class<?>[]{ManagedFileManagement.class};
	}

	@Override
	protected void startBundle() throws Exception {
		final ApacheHTTPClient client = new ApacheHTTPClient(getService(ManagedFileManagement.class));
		@SuppressWarnings("rawtypes")
		SimpleRegistryListener<HTTPResponseProcessor> listener = new SimpleRegistryListener<HTTPResponseProcessor>() {

			@Override
            public void added(ServiceReference<HTTPResponseProcessor> ref,
					HTTPResponseProcessor service) {
				client.registerProcessor(service);
			}

			@Override
            public void removed(ServiceReference<HTTPResponseProcessor> ref,
					HTTPResponseProcessor service) {
				client.forgetProcessor(service);
			}


		};
		track(HTTPResponseProcessor.class, listener );
		
		openTrackers();
		
		registerService(HTTPClient.class, client);
	}
}

==> open-xchange-core_7.8.4.orig.tar.bz2: open-xchange-core-7.8.4/com.openexchange.http.client/src/com/openexchange/http/client/osgi/HTTPClientActivator.java <==
/*-
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */


package com.openexchange.http.client.osgi;

import org.osgi.framework.ServiceReference;
import com.openexchange.filemanagement.ManagedFileManagement;
import com.openexchange.http.client.HTTPClient;
import com.openexchange.http.client.apache.ApacheHTTPClient;
import com.openexchange.http.client.builder.HTTPResponseProcessor;
import com.openexchange.net.ssl.SSLSocketFactoryProvider;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.osgi.SimpleRegistryListener;


public class HTTPClientActivator extends HousekeepingActivator {

	@Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { ManagedFileManagement.class, SSLSocketFactoryProvider.class };
	}

	@Override
	protected void startBundle() throws Exception {
	    Services.setServiceLookup(this);
		final ApacheHTTPClient client = new ApacheHTTPClient(getService(ManagedFileManagement.class));
		SimpleRegistryListener<HTTPResponseProcessor> listener = new SimpleRegistryListener<HTTPResponseProcessor>() {

			@Override
            public void added(ServiceReference<HTTPResponseProcessor> ref,
					HTTPResponseProcessor service) {
				client.registerProcessor(service);
			}

			@Override
            public void removed(ServiceReference<HTTPResponseProcessor> ref,
					HTTPResponseProcessor service) {
				client.forgetProcessor(service);
			}

		};
		track(HTTPResponseProcessor.class, listener );

		openTrackers();

		registerService(HTTPClient.class, client);
	}
}
